{
    "$graph": [
        {
            "doc": "Runs a wrapper script that randomly splits a BAM file, without replacement.\n",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.bam)"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "bam_split.sh"
            ],
            "arguments": [
                "$(inputs.bam.nameroot).split1.bam",
                "$(inputs.bam.nameroot).split2.bam"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_split.cwl/bam"
                }
            ],
            "id": "#bam_split.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).split1.bam"
                    },
                    "id": "#bam_split.cwl/split1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).split2.bam"
                    },
                    "id": "#bam_split.cwl/split2"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 16
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/ucsc-tools:377"
                }
            ],
            "baseCommand": [
                "bedToBigBed"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bed_to_bigbed.cwl/chrom_sizes"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "",
                    "id": "#bed_to_bigbed.cwl/input_bed"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 3,
                        "valueFrom": "${\n  if (inputs.output_bb_filename == \"\") {\n    return inputs.input_bed.nameroot + \".bb\";\n  }\n  else {\n    return inputs.output_bb_filename;\n  }\n}\n"
                    },
                    "id": "#bed_to_bigbed.cwl/output_bb_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_bb_filename == \"\") {\n    return inputs.input_bed.nameroot + \".bb\";\n  }\n  else {\n    return inputs.output_bb_filename;\n  }\n}\n"
                    },
                    "label": "",
                    "doc": "",
                    "id": "#bed_to_bigbed.cwl/output_bigbed"
                }
            ],
            "doc": "This tool converts an input-normalized eCLIP peaks file (BED6) into a bigbed (bb) file.\n",
            "id": "#bed_to_bigbed.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 8000
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/eclip:0.7.0_python"
                }
            ],
            "baseCommand": [
                "bed_to_narrowpeak.py"
            ],
            "arguments": [
                "--output_narrowpeak",
                "$(inputs.input_bed.nameroot).narrowPeak"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--input_bed"
                    },
                    "label": "",
                    "doc": "input bam to convert to narrowPeak format. Must be ECLIP-style input-normed format! (log10p in col4, log2fold in col5)",
                    "id": "#bed_to_narrowpeak.cwl/input_bed"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--species"
                    },
                    "id": "#bed_to_narrowpeak.cwl/species"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bed.nameroot).narrowPeak"
                    },
                    "label": "",
                    "doc": "eCLIP peaks in narrowPeak format",
                    "id": "#bed_to_narrowpeak.cwl/output_narrowpeak"
                }
            ],
            "doc": "This tool converts an input-normalized eCLIP peaks file (BED6) into a narrowPeak format for encode DCC. \ncols 9 and 10 are just blank, col 5 is 1000 for things that meet the >=3 l2fc and l10pval cutoffs and 200 otherwise (it\u2019s just for ucsc track coloring)\n",
            "id": "#bed_to_narrowpeak.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/samtools:1.6"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": "BAM file",
                    "id": "#calculate_readnum.cwl/bamFile"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "default": true,
                    "label": "Print only the count",
                    "id": "#calculate_readnum.cwl/countFlag"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-F"
                    },
                    "default": 4,
                    "label": "Flag to count only the mapped reads",
                    "id": "#calculate_readnum.cwl/readFlag"
                }
            ],
            "stdout": "$(inputs.bamFile.nameroot).readnum",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bamFile.nameroot).readnum"
                    },
                    "id": "#calculate_readnum.cwl/readnum"
                }
            ],
            "doc": "returns the number of reads inside a *.readnum file\n",
            "id": "#calculate_readnum.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 32000
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/clipper:5d865bb"
                }
            ],
            "baseCommand": [
                "clipper"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bam"
                    },
                    "id": "#clipper.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--gene"
                    },
                    "id": "#clipper.cwl/gene"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--outfile",
                        "valueFrom": "${\n  if (inputs.outfile == \"\") {\n    return inputs.bam.nameroot + \".peakClusters.bed\";\n  }\n  else {\n    return inputs.outfile;\n  }\n}\n"
                    },
                    "id": "#clipper.cwl/outfile"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--species"
                    },
                    "doc": "species: one of ce10 ce11 dm3 hg19 GRCh38 mm9 mm10 GRCh38_pU6 GRCh38_v29 GRCh38_v29e hg19_VSV",
                    "id": "#clipper.cwl/species"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outfile == \"\") {\n    return inputs.bam.nameroot + \".peakClusters.bed\";\n  }\n  else {\n    return inputs.outfile;\n  }\n}\n"
                    },
                    "id": "#clipper.cwl/output_bed"
                }
            ],
            "doc": "CLIPper is a tool to define peaks in your CLIP-seq dataset.\nCLIPper was developed in the Yeo Lab at the University of California, San Diego.\n  Usage: clipper --bam CLIP-seq_reads.srt.bam --species hg19 --outfile CLIP-seq_reads.srt.peaks.bed\n",
            "id": "#clipper.cwl"
        },
        {
            "doc": "This tool wraps compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.pl,\nwhich merges neighboring or overlapping regions in a BED file.\n  Usage:   perl compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat.pl <in.bed> <out.compressed.bed>\n",
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.pl"
            ],
            "arguments": [
                "$(inputs.input_full.nameroot).compressed.bed",
                "$(inputs.input_full.nameroot).compressed.bed.full"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/input_full"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_full.nameroot).compressed.bed"
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/output_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_full.nameroot).compressed.bed.full"
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/output_full"
                }
            ],
            "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl"
        },
        {
            "doc": "Returns string expression based on file contents.\n",
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#file2int.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "id": "#file2int.cwl/output"
                }
            ],
            "expression": "${return {'output':parseInt(inputs.file.contents)}; }",
            "id": "#file2int.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 8000
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/eclip:0.7.0_python"
                }
            ],
            "baseCommand": [
                "fix_bed_for_bigbed_conversion.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--input_bed"
                    },
                    "label": "",
                    "doc": "input bed (eCLIP input-normalized format) to be fixed (ie. change col4 to string, col5 to integer) for bigbed conversion",
                    "id": "#fix_bed_for_bigbed_conversion.cwl/input_bed"
                }
            ],
            "arguments": [
                "--output_fixed_bed",
                "$(inputs.input_bed.nameroot).fx.bed"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bed.nameroot).fx.bed"
                    },
                    "label": "",
                    "doc": "eCLIP peaks in proper BED6 format",
                    "id": "#fix_bed_for_bigbed_conversion.cwl/output_fixed_bed"
                }
            ],
            "doc": "This tool fixes the eCLIP input-normalized format to the proper BED6 format prior to bigbed conversion.\n",
            "id": "#fix_bed_for_bigbed_conversion.cwl"
        },
        {
            "doc": "Converts a full file into a bed6 formatted file.\n",
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "full_to_bed.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--input"
                    },
                    "id": "#full_to_bed.cwl/full"
                }
            ],
            "arguments": [
                "--output",
                "$(inputs.full.nameroot).bed"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.full.nameroot).bed"
                    },
                    "id": "#full_to_bed.cwl/bed"
                }
            ],
            "id": "#full_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "get_reproducing_peaks.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 9
                    },
                    "id": "#get_reproducing_peaks.cwl/idr_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "final reproducible peaks (BED6 format)",
                    "id": "#get_reproducing_peaks.cwl/output_bed"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "final reproducible peaks (BED+extra cols format)",
                    "id": "#get_reproducing_peaks.cwl/output_custombed"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#get_reproducing_peaks.cwl/rep1_entropy_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "rep1 full out after idr (.01.bed.full or rep1.bed.full)",
                    "id": "#get_reproducing_peaks.cwl/rep1_full_in"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "rep1 full out after this step",
                    "id": "#get_reproducing_peaks.cwl/rep1_full_output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#get_reproducing_peaks.cwl/rep2_entropy_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "rep1 full out after idr (.02.bed.full or rep2.bed.full)",
                    "id": "#get_reproducing_peaks.cwl/rep2_full_in"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "rep2 full out after this step",
                    "id": "#get_reproducing_peaks.cwl/rep2_full_output"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_bed)"
                    },
                    "id": "#get_reproducing_peaks.cwl/output_bed_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_custombed)"
                    },
                    "id": "#get_reproducing_peaks.cwl/output_custombed_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.rep1_full_output)"
                    },
                    "id": "#get_reproducing_peaks.cwl/rep1_full_output_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.rep2_full_output)"
                    },
                    "id": "#get_reproducing_peaks.cwl/rep2_full_output_file"
                }
            ],
            "id": "#get_reproducing_peaks.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/idr:2.0.2"
                }
            ],
            "baseCommand": [
                "idr"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--input-file-type"
                    },
                    "default": "bed",
                    "id": "#idr.cwl/inputFileType"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-o"
                    },
                    "id": "#idr.cwl/outputFilename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--peak-merge-method"
                    },
                    "default": "max",
                    "id": "#idr.cwl/peakMergeMethod"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--plot"
                    },
                    "default": true,
                    "id": "#idr.cwl/plot"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--rank"
                    },
                    "default": 5,
                    "id": "#idr.cwl/rank"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samples"
                    },
                    "doc": "input bed file",
                    "id": "#idr.cwl/samples"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputFilename)"
                    },
                    "id": "#idr.cwl/output"
                }
            ],
            "id": "#idr.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "linescount.sh"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#linescount.cwl/textfile"
                }
            ],
            "stdout": "$(inputs.textfile.basename).linescount",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.textfile.basename).linescount"
                    },
                    "id": "#linescount.cwl/linescount"
                }
            ],
            "id": "#linescount.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "make_informationcontent_from_peaks.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "A file containing a single number corresponding to the number of mapped reads (-cF 4) in CLIP",
                    "id": "#make_informationcontent_from_peaks.cwl/clip_read_num"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/compressed_bed_full"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "A file containing a single number corresponding to the number of mapped reads (-cF 4) in INPUT",
                    "id": "#make_informationcontent_from_peaks.cwl/input_read_num"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "${\n  if (inputs.output_excess_reads == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.excessreads\";\n  }\n  else {\n    return inputs.output_excess_reads;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/output_excess_reads"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 4,
                        "valueFrom": "${\n  if (inputs.output_file == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.full\";\n  }\n  else {\n    return inputs.output_file;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/output_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_excess_reads == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.excessreads\";\n  }\n  else {\n    return inputs.output_excess_reads;\n  }\n}"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_file == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.full\";\n  }\n  else {\n    return inputs.output_file;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/entropy_full"
                }
            ],
            "id": "#make_informationcontent_from_peaks.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "overlap_peakfi_with_bam.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -5
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/clipBamFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/clipReadnum"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputBamFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputReadnum"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 0,
                        "valueFrom": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/outputFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -3
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/peakFile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputnormedBed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed.full\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputnormedBedfull"
                }
            ],
            "doc": "This tool wraps overlap_peakfi_with_bam_PE.pl\n  Usage:\n",
            "id": "#overlap_peakfi_with_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "parse_idr_peaks.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#parse_idr_peaks.cwl/entropyFile1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#parse_idr_peaks.cwl/entropyFile2"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#parse_idr_peaks.cwl/idrFile"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#parse_idr_peaks.cwl/outputFilename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputFilename)"
                    },
                    "id": "#parse_idr_peaks.cwl/output"
                }
            ],
            "doc": "returns the",
            "id": "#parse_idr_peaks.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/samtools:1.6"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        "$(inputs.alignments)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "valueFrom": "$(self.basename)"
                    },
                    "label": "Input bam file.",
                    "id": "#samtools-index.cwl/alignments"
                }
            ],
            "baseCommand": [
                "samtools",
                "index",
                "-b"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "outputBinding": {
                        "glob": "$(inputs.alignments.basename)"
                    },
                    "doc": "The index file",
                    "id": "#samtools-index.cwl/alignments_with_index"
                }
            ],
            "doc": "samtools-index.cwl is developed for CWL consortium\n",
            "id": "#samtools-index.cwl",
            "http://schema.org/mainEntity": null,
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/sameAs": [
                    {
                        "id": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center",
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ]
                    }
                ]
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 8000
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/bedtools:2.27.1"
                }
            ],
            "baseCommand": [
                "sort"
            ],
            "arguments": [
                "-k1,1",
                "-k2,2n"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#sort-bed.cwl/unsorted_bed"
                }
            ],
            "stdout": "$(inputs.unsorted_bed.nameroot).sorted.bed",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.unsorted_bed.nameroot).sorted.bed"
                    },
                    "id": "#sort-bed.cwl/sorted_bed"
                }
            ],
            "doc": "This tool wraps unix sort to sort a BED file.\n\nUsage: sort -k1,1 -k2,2n unsorted.bed > sorted.bed\n",
            "id": "#sort-bed.cwl"
        },
        {
            "doc": "The main workflow that produces two reproducible peaks via IDR given\ntwo eCLIP samples (1 input, 1 IP each).\n",
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/chrom_sizes"
                },
                {
                    "type": "string",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/merged_peaks_bed"
                },
                {
                    "type": "string",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/merged_peaks_custombed"
                },
                {
                    "type": "File",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_clip_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_peaks_bed_file"
                },
                {
                    "type": "File",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_clip_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_peaks_bed_file"
                },
                {
                    "type": "string",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/species"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/idr/output",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/idr_output"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/output",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/idr_output_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_bed_file",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/merged_peaks_bed_file"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_custombed_file",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/merged_peaks_custombed_file"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_bigbed/output_bigbed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/output_bigbed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_narrowpeak/output_narrowpeak",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/output_narrowpeak"
                },
                {
                    "doc": "file containing mapped reads from rep1 clip BAM",
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/clip_read_num",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_clip_read_num"
                },
                {
                    "doc": "input normalized and compressed clip over input for rep1",
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/compressed_bed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_compressed_bed"
                },
                {
                    "doc": "entropy file re-formatted as a bed file for input to IDR",
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_bed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_entropy_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_excess_reads",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_entropy_excess_reads"
                },
                {
                    "doc": "input normalized clip over input for rep1 with entropy info",
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_full",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_entropy_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/inputnormedBed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_idr_output_input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/inputnormedBedfull",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_idr_output_input_normed_full"
                },
                {
                    "doc": "input normalized clip over input for rep1",
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_normed_bed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_normed_bed"
                },
                {
                    "doc": "input normalized clip over input for rep1 with read info",
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_normed_full",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_read_num",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep1_full_output_file",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_reproducing_peaks_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/clip_read_num",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/compressed_bed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_compressed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_bed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_entropy_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_excess_reads",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_full",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_entropy_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/inputnormedBed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_idr_output_input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/inputnormedBedfull",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_idr_output_input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_normed_bed",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_normed_full",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_read_num",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep2_full_output_file",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_reproducing_peaks_full"
                },
                {
                    "type": "int",
                    "outputSource": "#wf_get_reproducible_eclip_peaks.cwl/reproducible_peaks_file_to_int/output",
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/reproducing_peaks_count"
                }
            ],
            "steps": [
                {
                    "run": "#linescount.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_bed_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/count_reproducing_peaks/textfile"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/count_reproducing_peaks/linescount"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/count_reproducing_peaks"
                },
                {
                    "run": "#parse_idr_peaks.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_full",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/entropyFile1"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_full",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/entropyFile2"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/idr/output",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/idrFile"
                        },
                        {
                            "default": "01v02.idr.out.bed",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/outputFilename"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/output"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr"
                },
                {
                    "run": "#get_reproducing_peaks.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/idr/output",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/idr_file"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/merged_peaks_bed",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_bed"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/merged_peaks_custombed",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_custombed"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_full",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep1_entropy_file"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/inputnormedBedfull",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep1_full_in"
                        },
                        {
                            "default": "01v02.IDR.out.0102merged.01.full",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep1_full_output"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_full",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep2_entropy_file"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/inputnormedBedfull",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep2_full_in"
                        },
                        {
                            "default": "01v02.IDR.out.0102merged.02.full",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep2_full_output"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep1_full_output_file",
                        "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/rep2_full_output_file",
                        "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_bed_file",
                        "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_custombed_file"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks"
                },
                {
                    "run": "#idr.cwl",
                    "in": [
                        {
                            "default": "bed",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/idr/inputFileType"
                        },
                        {
                            "default": "01v02.idr.out",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/idr/outputFilename"
                        },
                        {
                            "default": "max",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/idr/peakMergeMethod"
                        },
                        {
                            "default": true,
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/idr/plot"
                        },
                        {
                            "default": 5,
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/idr/rank"
                        },
                        {
                            "source": [
                                "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_bed",
                                "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_bed"
                            ],
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/idr/samples"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/idr/output"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/idr"
                },
                {
                    "run": "#wf_input_norm_and_entropy.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_clip_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/clip_bam_file"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_bam_file"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_peaks_bed_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/peak_file"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/clip_read_num",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_read_num",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_normed_bed",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_normed_full",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/compressed_bed",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/compressed_full",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_full",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_excess_reads",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/entropy_bed"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy"
                },
                {
                    "run": "#overlap_peakfi_with_bam.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_clip_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/clipBamFile"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/clip_read_num",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/clipReadnum"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/inputBamFile"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_and_entropy/input_read_num",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/inputReadnum"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/output",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/peakFile"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/inputnormedBed",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks/inputnormedBedfull"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep1_input_norm_using_idr_peaks"
                },
                {
                    "run": "#wf_input_norm_and_entropy.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_clip_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/clip_bam_file"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_bam_file"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_peaks_bed_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/peak_file"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/clip_read_num",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_read_num",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_normed_bed",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_normed_full",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/compressed_bed",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/compressed_full",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_full",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_excess_reads",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/entropy_bed"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy"
                },
                {
                    "run": "#overlap_peakfi_with_bam.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_clip_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/clipBamFile"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/clip_read_num",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/clipReadnum"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_bam_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/inputBamFile"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_and_entropy/input_read_num",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/inputReadnum"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/create_bed_from_idr/output",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/peakFile"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/inputnormedBed",
                        "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks/inputnormedBedfull"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/rep2_input_norm_using_idr_peaks"
                },
                {
                    "run": "#file2int.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/count_reproducing_peaks/linescount",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/reproducible_peaks_file_to_int/file"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/reproducible_peaks_file_to_int/output"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/reproducible_peaks_file_to_int"
                },
                {
                    "run": "#bed_to_bigbed.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/chrom_sizes",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_bigbed/chrom_sizes"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/step_fix_bed_for_bigbed_conversion/output_fixed_bed",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_bigbed/input_bed"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_bigbed/output_bigbed"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_bigbed"
                },
                {
                    "run": "#bed_to_narrowpeak.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/step_sort_bed/sorted_bed",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_narrowpeak/input_bed"
                        },
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/species",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_narrowpeak/species"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_narrowpeak/output_narrowpeak"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/step_bed_to_narrowpeak"
                },
                {
                    "run": "#fix_bed_for_bigbed_conversion.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/step_sort_bed/sorted_bed",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/step_fix_bed_for_bigbed_conversion/input_bed"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/step_fix_bed_for_bigbed_conversion/output_fixed_bed"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/step_fix_bed_for_bigbed_conversion"
                },
                {
                    "run": "#sort-bed.cwl",
                    "in": [
                        {
                            "source": "#wf_get_reproducible_eclip_peaks.cwl/get_reproducing_peaks/output_bed_file",
                            "id": "#wf_get_reproducible_eclip_peaks.cwl/step_sort_bed/unsorted_bed"
                        }
                    ],
                    "out": [
                        "#wf_get_reproducible_eclip_peaks.cwl/step_sort_bed/sorted_bed"
                    ],
                    "id": "#wf_get_reproducible_eclip_peaks.cwl/step_sort_bed"
                }
            ],
            "id": "#wf_get_reproducible_eclip_peaks.cwl"
        },
        {
            "doc": "This workflow normalizes clip aligned reads against a size-matched input\nsample. Then, an entropy score is calculated for each peak found.\n",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#wf_input_norm_and_entropy.cwl/clip_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_input_norm_and_entropy.cwl/input_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_input_norm_and_entropy.cwl/peak_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum",
                    "id": "#wf_input_norm_and_entropy.cwl/clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/compress_peaks/output_bed",
                    "id": "#wf_input_norm_and_entropy.cwl/compressed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/compress_peaks/output_full",
                    "id": "#wf_input_norm_and_entropy.cwl/compressed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull/bed",
                    "id": "#wf_input_norm_and_entropy.cwl/entropy_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_excess_reads",
                    "id": "#wf_input_norm_and_entropy.cwl/entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_full",
                    "id": "#wf_input_norm_and_entropy.cwl/entropy_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/input_norm/inputnormedBed",
                    "id": "#wf_input_norm_and_entropy.cwl/input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/input_norm/inputnormedBedfull",
                    "id": "#wf_input_norm_and_entropy.cwl/input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum",
                    "id": "#wf_input_norm_and_entropy.cwl/input_read_num"
                }
            ],
            "steps": [
                {
                    "run": "#calculate_readnum.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/clip_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/bamFile"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum"
                },
                {
                    "run": "#calculate_readnum.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/input_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/bamFile"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum"
                },
                {
                    "run": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/input_norm/inputnormedBedfull",
                            "id": "#wf_input_norm_and_entropy.cwl/compress_peaks/input_full"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/compress_peaks/output_bed",
                        "#wf_input_norm_and_entropy.cwl/compress_peaks/output_full"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/compress_peaks"
                },
                {
                    "run": "#full_to_bed.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_full",
                            "id": "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull/full"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull/bed"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull"
                },
                {
                    "run": "#overlap_peakfi_with_bam.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/clip_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/clipBamFile"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/clipReadnum"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/input_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/inputBamFile"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/inputReadnum"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/peak_file",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/peakFile"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/input_norm/inputnormedBed",
                        "#wf_input_norm_and_entropy.cwl/input_norm/inputnormedBedfull"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/input_norm"
                },
                {
                    "run": "#make_informationcontent_from_peaks.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/clip_read_num"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/compress_peaks/output_full",
                            "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/compressed_bed_full"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/input_read_num"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_full",
                        "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_excess_reads"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks"
                }
            ],
            "id": "#wf_input_norm_and_entropy.cwl"
        },
        {
            "doc": "This workflow returns the reproducible number of split peaks given a single\nbam file and its size-matched input pair. This workflow splits the bam file\nfirst, but does not do anything to the input. \n",
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/chrom_sizes"
                },
                {
                    "type": "File",
                    "id": "#main/clip_bam"
                },
                {
                    "type": "File",
                    "id": "#main/input_bam"
                },
                {
                    "type": "string",
                    "id": "#main/merged_peaks_bed"
                },
                {
                    "type": "string",
                    "id": "#main/merged_peaks_custombed"
                },
                {
                    "type": "string",
                    "id": "#main/species"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/step_reproducible_peaks_num/merged_peaks_bed_file",
                    "id": "#main/merged_peaks_bed_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/step_reproducible_peaks_num/rep1_clip_read_num",
                    "id": "#main/rep1_clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/step_reproducible_peaks_num/rep1_input_read_num",
                    "id": "#main/rep1_input_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/step_reproducible_peaks_num/rep2_clip_read_num",
                    "id": "#main/rep2_clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/step_reproducible_peaks_num/rep2_input_read_num",
                    "id": "#main/rep2_input_read_num"
                },
                {
                    "type": "int",
                    "outputSource": "#main/step_reproducible_peaks_num/reproducing_peaks_count",
                    "id": "#main/reproducing_peaks_count"
                }
            ],
            "steps": [
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/step_bam_split/split1",
                            "id": "#main/index_split1/alignments"
                        }
                    ],
                    "out": [
                        "#main/index_split1/alignments_with_index"
                    ],
                    "id": "#main/index_split1"
                },
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/step_bam_split/split2",
                            "id": "#main/index_split2/alignments"
                        }
                    ],
                    "out": [
                        "#main/index_split2/alignments_with_index"
                    ],
                    "id": "#main/index_split2"
                },
                {
                    "run": "#bam_split.cwl",
                    "in": [
                        {
                            "source": "#main/clip_bam",
                            "id": "#main/step_bam_split/bam"
                        }
                    ],
                    "out": [
                        "#main/step_bam_split/split1",
                        "#main/step_bam_split/split2"
                    ],
                    "id": "#main/step_bam_split"
                },
                {
                    "run": "#clipper.cwl",
                    "in": [
                        {
                            "source": "#main/index_split1/alignments_with_index",
                            "id": "#main/step_clipper_split1/bam"
                        },
                        {
                            "source": "#main/species",
                            "id": "#main/step_clipper_split1/species"
                        }
                    ],
                    "out": [
                        "#main/step_clipper_split1/output_bed"
                    ],
                    "id": "#main/step_clipper_split1"
                },
                {
                    "run": "#clipper.cwl",
                    "in": [
                        {
                            "source": "#main/index_split2/alignments_with_index",
                            "id": "#main/step_clipper_split2/bam"
                        },
                        {
                            "source": "#main/species",
                            "id": "#main/step_clipper_split2/species"
                        }
                    ],
                    "out": [
                        "#main/step_clipper_split2/output_bed"
                    ],
                    "id": "#main/step_clipper_split2"
                },
                {
                    "run": "#wf_get_reproducible_eclip_peaks.cwl",
                    "in": [
                        {
                            "source": "#main/chrom_sizes",
                            "id": "#main/step_reproducible_peaks_num/chrom_sizes"
                        },
                        {
                            "source": "#main/merged_peaks_bed",
                            "id": "#main/step_reproducible_peaks_num/merged_peaks_bed"
                        },
                        {
                            "source": "#main/merged_peaks_custombed",
                            "id": "#main/step_reproducible_peaks_num/merged_peaks_custombed"
                        },
                        {
                            "source": "#main/step_bam_split/split1",
                            "id": "#main/step_reproducible_peaks_num/rep1_clip_bam_file"
                        },
                        {
                            "source": "#main/input_bam",
                            "id": "#main/step_reproducible_peaks_num/rep1_input_bam_file"
                        },
                        {
                            "source": "#main/step_clipper_split1/output_bed",
                            "id": "#main/step_reproducible_peaks_num/rep1_peaks_bed_file"
                        },
                        {
                            "source": "#main/step_bam_split/split2",
                            "id": "#main/step_reproducible_peaks_num/rep2_clip_bam_file"
                        },
                        {
                            "source": "#main/input_bam",
                            "id": "#main/step_reproducible_peaks_num/rep2_input_bam_file"
                        },
                        {
                            "source": "#main/step_clipper_split2/output_bed",
                            "id": "#main/step_reproducible_peaks_num/rep2_peaks_bed_file"
                        },
                        {
                            "source": "#main/species",
                            "id": "#main/step_reproducible_peaks_num/species"
                        }
                    ],
                    "out": [
                        "#main/step_reproducible_peaks_num/reproducing_peaks_count",
                        "#main/step_reproducible_peaks_num/output_narrowpeak",
                        "#main/step_reproducible_peaks_num/output_bigbed",
                        "#main/step_reproducible_peaks_num/rep1_clip_read_num",
                        "#main/step_reproducible_peaks_num/rep1_input_read_num",
                        "#main/step_reproducible_peaks_num/rep2_clip_read_num",
                        "#main/step_reproducible_peaks_num/rep2_input_read_num",
                        "#main/step_reproducible_peaks_num/merged_peaks_bed_file"
                    ],
                    "id": "#main/step_reproducible_peaks_num"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ]
}
